@@ -33,13 +33,6 @@
 #include <abort-instr.h>
 #include <tls.h>
 
-# define VALID_ELF_OSABI(osabi)		((osabi == ELFOSABI_SYSV) || (osabi == ELFOSABI_LINUX))
-# define VALID_ELF_ABIVERSION(ver)	(ver == 0)
-# define VALID_ELF_HEADER(hdr,exp,size) \
-  memcmp (hdr,exp,size-2) == 0 \
-  && VALID_ELF_OSABI (hdr[EI_OSABI]) \
-  && VALID_ELF_ABIVERSION (hdr[EI_ABIVERSION])
-
 /* These two definitions must match the definition of the stub in 
    bfd/elf32-hppa.c (see plt_stub[]).
    
@@ -233,7 +226,7 @@ elf_machine_runtime_setup (struct link_map *l, int lazy, int profile)
                       GL(dl_profile_map) = l;
                     }
 
-		  if((unsigned long) &_dl_runtime_resolve & 3)
+		  if((unsigned long) &_dl_runtime_profile & 3)
 		    {
                       got[-2] = (Elf32_Addr) ((struct fdesc *)
                                   ((unsigned long) &_dl_runtime_profile & ~3))->ip;
